import { Router } from "express";
import { body } from "express-validator";
import handleValidationResult from "../middleware/handleValidationResult";
import validateToken from "../middleware/validateToken";
import { createAccountController } from "../controllers/accounts.controllers";

const accountsRouter = Router();

accountsRouter.post(
  "/api/accounts/",
  body("first_name").not().isEmpty(),
  body("last_name").not().isEmpty(),
  body("email").isEmail().normalizeEmail(),
  body("role").isIn(["coordinator", "boatManager"]),
  body("password").isLength({ min: 6 }),
  handleValidationResult,
  validateToken,
  createAccountController
);

export default accountsRouter;
